==> ScriptDeploy-0.4.tar: ScriptDeploy-0.4/action.default.php <==
<?php
#-------------------------------------------------------------------------
# Module: ScriptDeploy - Minify and deployment of JS CSS and HTML 
# Mod designed by jeremyBass (jeremyBass@cableone.net)
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
# The module's homepage is: http://dev.cmsmadesimple.org/projects/ScriptDeploy/
#-------------------------------------------------------------------------
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#-------------------------------------------------------------------------
if (!isset($gCms)) exit;
 //$this->AddEventForm($id, $params, $returnid);
	//global $gCms;
	$config =& $gCms->GetConfig(); 
	if(isset($params['scriptID'])){
		$ID=$params['scriptID'];
		$type="scriptID";
	}elseif(isset($params['groupID'])){
		$ID=$params['groupID'];	
		$type="groupID";
	}
	
	$Subdir=$type.'-'.$ID;
	$filebasename=$ID;

	$Stype= isset($params['Stype']) ? $params['Stype']:'';
	$noOutPut = isset($params['noOutPut']) ? $params['noOutPut']:false;
	$filename=$config['uploads_path']."/lib/SD-temp/".$Subdir."/".$filebasename.".".$Stype;	

	if(file_exists($filename)){
		if($debugIT==true){
				unlink ($filename);
		}
	}

	if(!file_exists($filename)){
		$SmartyOn= isset($params['SmartyOn']) ? $params['SmartyOn']:true;
		$data=$this->filestime($ID,$type,$SmartyOn);
		$event='';
		//$event=JSMin::minify($data[0]);
			$arg2 = null;
			switch ($Stype) {
			case 'JS':
				$typeIS = 'Javascript';
				break;
			case 'CSS':
				$typeIS = 'CSS';
				break;
			case 'html':
				$typeIS = 'HTML';
				$arg2 = array(
					'cssMinifier' => array('Minify_CSS', 'minify')
					,'jsMinifier' => array('Minify_Javascript', 'minify')
				);
			}
			$func = array('Minify_' . $typeIS, 'minify');

		$Minify= isset($params['Minify']) ? $params['Minify']:true;
		if($Minify==true){
				$event = call_user_func($func, $data[0], $arg2);
		}else{
			$event = $data[0];
		}
		
		

		if(!file_exists($config['uploads_path']."/lib/SD-temp/".$Subdir)){
			mkdir($config['uploads_path']."/lib/SD-temp/".$Subdir, 0777, true);
		}
		$ourFileName = $filename;
		$ourFileHandle = fopen($ourFileName, 'w') or die("can't open file");
		fclose($ourFileHandle);
		// GET LENGTH, AND STORE DATA TO OUR SERVER (OR DATA BASE)
		$len = strlen($event);
		$chk = file_put_contents($filename, $event);
		// TEST FOR SUCCESSFUL STORAGE
		if ($len!=$chk) die("LENGTH MISMATCH");
	}
	if($noOutPut==false){
		$assign = isset($params['assign']) ? $params['assign']:'';
		$cacheBuster= isset($params['cacheBuster']) ? $params['cacheBuster']:$this->GetPreference('cacheBuster',false);
		$fsize = isset($params['fsize']) ? $params['fsize']:false;
		$rootUrl = isset($params['rootUrl']) ? $params['rootUrl'] : $config['uploads_url'];
		$URL= isset($params['URL']) ? $params['URL']:0;
		
		$fileLINK=$rootUrl."/lib/SD-temp/".$Subdir."/".$filebasename.".".$Stype;
		
		if($cacheBuster==true){
			$fileLINK=$fileLINK."?".filemtime($filename);
		}
		$Tag='';
		$MediaType = isset($params['MediaType']) ? $params['MediaType']:'all';
		$import = isset($params['import']) ? $params['import']:false;
		if($Stype=='JS'){
			$Tag="<script type=\"text/javascript\" src=\"$fileLINK\"></script>";
		}elseif($Stype=='CSS'){
			if($import==false){
			$Tag="<link rel=\"stylesheet\" media=\"$MediaType\" type=\"text/css\" href=\"$fileLINK\" />";
			}else{
			$Tag="<style type=\"text/css\">@import url($fileLINK) $MediaType;</style>";
			}
		}

		if($URL==false){
			if($assign!=''){
				$this->smarty->assign($assign,$Tag);
			}else{
				echo $Tag;
			}
		}else{
			if($assign!=''){
					$this->smarty->assign($assign,$fileLINK);			
			}else{
				if($fsize==true){
					echo $this->SizeItUp(filesize($filename));
				}else{
					echo $fileLINK;
				}
			}
		}
	}
?>

==> ScriptDeploy-0.5.tar: ScriptDeploy-0.5/action.default.php <==
<?php
#-------------------------------------------------------------------------
# Module: ScriptDeploy - Minify and deployment of JS CSS and HTML 
# Mod designed by jeremyBass (jeremyBass@cableone.net)
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
# The module's homepage is: http://dev.cmsmadesimple.org/projects/ScriptDeploy/
#-------------------------------------------------------------------------
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#-------------------------------------------------------------------------
if (!isset($gCms)) exit;
 //$this->AddEventForm($id, $params, $returnid);
	//global $gCms;
	$config =& $gCms->GetConfig(); 
	if(isset($params['scriptID'])){
		$ID=$params['scriptID'];
		$type="scriptID";
	}elseif(isset($params['groupID'])){
		$ID=$params['groupID'];	
		$type="groupID";
	}
	
	$Subdir=$type.'-'.$ID;
	$filebasename=$ID;

	$Stype= isset($params['Stype']) ? $params['Stype']:'';
	$noOutPut = isset($params['noOutPut']) ? $params['noOutPut']:false;
	$filename=$config['uploads_path']."/lib/SD-temp/".$Subdir."/".$filebasename.".".strtolower($Stype);	
	$debugIT=$this->GetPreference('debugIT');
	if(file_exists($filename)){
		if($debugIT==true){
				unlink ($filename);
		}
	}

	if(!file_exists($filename)){
		$SmartyOn= isset($params['SmartyOn']) ? $params['SmartyOn']:true;
		$data=$this->filestime($ID,$type,$SmartyOn);
		$event='';
		//$event=JSMin::minify($data[0]);
			$arg2 = null;
			switch ($Stype) {
			case 'JS':
				$typeIS = 'Javascript';
				break;
			case 'CSS':
				$typeIS = 'CSS';
				break;
			case 'html':
				$typeIS = 'HTML';
				$arg2 = array(
					'cssMinifier' => array('Minify_CSS', 'minify')
					,'jsMinifier' => array('Minify_Javascript', 'minify')
				);
			}
			$func = array('Minify_' . $typeIS, 'minify');

		$Minify= isset($params['Minify']) ? $params['Minify']:true;
		if($Minify==true){
				$event = call_user_func($func, $data[0], $arg2);
		}else{
			$event = $data[0];
		}
		
		

		if(!file_exists($config['uploads_path']."/lib/SD-temp/".$Subdir)){
			mkdir($config['uploads_path']."/lib/SD-temp/".$Subdir, 0777, true);
		}
		$ourFileName = $filename;
		$ourFileHandle = fopen($ourFileName, 'w') or die("can't open file");
		fclose($ourFileHandle);
		// GET LENGTH, AND STORE DATA TO OUR SERVER (OR DATA BASE)
		$len = strlen($event);
		$chk = file_put_contents($filename, $event);
		// TEST FOR SUCCESSFUL STORAGE
		if ($len!=$chk) die("LENGTH MISMATCH");
	}
	if($noOutPut==false){
		$assign = isset($params['assign']) ? $params['assign']:'';
		$cacheBuster= isset($params['cacheBuster']) ? $params['cacheBuster']:$this->GetPreference('cacheBuster',false);
		$fsize = isset($params['fsize']) ? $params['fsize']:false;
		$rootUrl = isset($params['rootUrl']) ? $params['rootUrl'] : $config['uploads_url'];
		$URL= isset($params['URL']) ? $params['URL']:0;
		
		$fileLINK=$rootUrl."/lib/SD-temp/".$Subdir."/".$filebasename.".".strtolower($Stype);
		
		if($cacheBuster==true){
			$fileLINK=$fileLINK."?".filemtime($filename);
		}
		$Tag='';
		$MediaType = isset($params['MediaType']) ? $params['MediaType']:'all';
		$import = isset($params['import']) ? $params['import']:false;
		if($Stype=='JS'){
			$Tag="<script type=\"text/javascript\" src=\"$fileLINK\"></script>";
		}elseif($Stype=='CSS'){
			if($import==false){
			$Tag="<link rel=\"stylesheet\" media=\"$MediaType\" type=\"text/css\" href=\"$fileLINK\" />";
			}else{
			$Tag="<style type=\"text/css\">@import url($fileLINK) $MediaType;</style>";
			}
		}

		if($URL==false){
			if($assign!=''){
				$this->smarty->assign($assign,$Tag);
			}else{
				echo $Tag;
			}
		}else{
			if($assign!=''){
					$this->smarty->assign($assign,$fileLINK);			
			}else{
				if($fsize==true){
					echo $this->SizeItUp(filesize($filename));
				}else{
					echo $fileLINK;
				}
			}
		}
	}
?>
